--
-- teleskopAxle
-- Specialization for teleskopAxle
--

teleskopAxle = {};

function teleskopAxle.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(AnimatedVehicle, specializations);
end

function teleskopAxle:getSaveAttributesAndNodes(nodeIdent)
	local attributes = 'teleskopAxleState="'..tostring(Utils.getNoNil(self.teleskopAxleState))
	attributes = attributes ..'"';
	return attributes
end;

function teleskopAxle:load(savegame)
    self.teleskopAxleAnimation = getXMLString(self.xmlFile, "vehicle.teleskopAxle#animationName");	
    self.teleskopAxleVisibleNode = Utils.indexToObject(self.components, getXMLString(self.xmlFile, "vehicle.teleskopAxle#visiblenode"));	
	self.teleskopAxleVisible = false
	self.teleskopAxleState = 1
	
    if savegame ~= nil and not savegame.resetVehicles then
		local saveStateteleskopAxle = Utils.getNoNil(getXMLFloat(savegame.xmlFile, savegame.key.."#teleskopAxleState"));
		if saveStateteleskopAxle == 1 then
			self:playAnimation(self.teleskopAxleAnimation, 80, nil, true);--Teleskopachse einfahren
			self.teleskopAxleState = 1
		elseif saveStateteleskopAxle == 2 then
			self:playAnimation(self.teleskopAxleAnimation, -80, nil, true);--Teleskopachse ausfahren
			self.teleskopAxleState = 2
		end
	else
		self:playAnimation(self.teleskopAxleAnimation, 80, nil, true);--Teleskopachse einfahren
		self.teleskopAxleState = 1
	end
end

function teleskopAxle:postLoad(savegame)
end;

function teleskopAxle:readStream(streamId, connection)
    if connection:getIsServer() then
		self.teleskopAxleState = streamReadFloat32(streamId); 
		local StateAxle = self.teleskopAxleState
		if StateAxle == 1 then
			self:playAnimation(self.teleskopAxleAnimation, 50, nil, true);--Teleskopachse einfahren
			self.teleskopAxleState = 1
		elseif StateAxle == 2 then
			self:playAnimation(self.teleskopAxleAnimation, -50, nil, true);--Teleskopachse ausfahren
			self.teleskopAxleState = 2
		end		
	end
end;

function teleskopAxle:writeStream(streamId, connection)
    if not connection:getIsServer() then
		streamWriteFloat32(streamId, self.teleskopAxleState);		
	end
end

function teleskopAxle:update(dt)
	if self:getIsActive() then
		if self.isClient and self:getIsActiveForInput(true) then
			if self.teleskopAxleAnimation ~= nil then
				local AxleVisible = false
				if self.teleskopAxleAnimation ~= nil then
					AxleVisible = getVisibility(self.teleskopAxleVisibleNode)
					self.teleskopAxleVisible = AxleVisible
				end
				if self.teleskopAxleVisible == true then
					if InputBinding.hasEvent(InputBinding.IMPLEMENT_EXTRA2) then	
						if self.teleskopAxleState == 1 then
							self:playAnimation(self.teleskopAxleAnimation, -1, nil, false);--Teleskopachse ausfahren
							self.teleskopAxleState = 2
							if g_server ~= nil then
								g_server:broadcastEvent(teleskopAxleState_Event:new(self, self.teleskopAxleState), nil, nil, self);
							else
								g_client:getServerConnection():sendEvent(teleskopAxleState_Event:new(self, self.teleskopAxleState));
							end;										
						elseif self.teleskopAxleState == 2 then
							self:playAnimation(self.teleskopAxleAnimation, 1, nil, false);--Teleskopachse einfahren
							self.teleskopAxleState = 1
							if g_server ~= nil then
								g_server:broadcastEvent(teleskopAxleState_Event:new(self, self.teleskopAxleState), nil, nil, self);
							else
								g_client:getServerConnection():sendEvent(teleskopAxleState_Event:new(self, self.teleskopAxleState));
							end;										
						end
					end
				end
			end
		end
	end
end

function teleskopAxle:draw()
    if self.isClient and self:getIsActiveForInput(true) then
		if self.teleskopAxleVisible == true then
			 g_currentMission:addHelpButtonText(string.format(g_i18n:getText("move_TeleskopAxle")), InputBinding.IMPLEMENT_EXTRA2, nil, GS_PRIO_HIGH)		
		end
	end
end

function teleskopAxle:delete()
end;

function teleskopAxle:mouseEvent(posX, posY, isDown, isUp, button)
end;

function teleskopAxle:keyEvent(unicode, sym, modifier, isDown)
end;

function teleskopAxle:onAttach()
end; 	

function teleskopAxle:onDetach()
end;

-- Event fuer Synchro --
teleskopAxleState_Event = {};
teleskopAxleState_Event_mt = Class(teleskopAxleState_Event, Event);
 
InitEventClass(teleskopAxleState_Event, "teleskopAxleState_Event");
  
function teleskopAxleState_Event:emptyNew()
    local self = Event:new(teleskopAxleState_Event_mt);
    return self;
end;
  
function teleskopAxleState_Event:new(object, data3)
    local self = teleskopAxleState_Event:emptyNew()
    self.data3 = data3;
  
    self.object = object;
    return self;
end;
  
function teleskopAxleState_Event:readStream(streamId, connection)
    local id = streamReadInt32(streamId);
    self.data3 = streamReadFloat32(streamId);
      
	  
	self.object = networkGetObject(id);
    self:run(connection);
end;
  
function teleskopAxleState_Event:writeStream(streamId, connection)
    streamWriteInt32(streamId, networkGetObjectId(self.object));
    streamWriteFloat32(streamId, self.data3);
end;
  
function teleskopAxleState_Event:run(connection)
    self.object.teleskopAxleState = self.data3;

    if not connection:getIsServer() then
        g_server:broadcastEvent(teleskopAxleState_Event:new(self.object, self.data3), nil, connection, self.object);
    end;
end;
  